@@ -1,12 +1,11 @@
 #' An S4 class to represent a dosefinding results.
 #'
-#' @slot model A character string to specify the working model used in the method.
-#' @slot pid Patient ID provided in the study.
+#' @slot pid Patient's ID provided in the study.
 #' @slot N  The total number of patients.
 #' @slot time The time sampling.
-#' @slot dose The doses levels of the drug.
+#' @slot dose The dose levels of the drug.
 #' @slot conc Concentration of the drug.
-#' @slot p_0  Skeleton of CRM. 
+#' @slot p_0  The skeleton of CRM. 
 #' @slot L  A threshold set before starting the trial.
 #' @slot nchains Number of chains for the stan model.
 #' @slot niter Number of iterations for the stan model.
@@ -16,29 +15,30 @@
 #' @slot dose_levels A vector of dose levels assigned to patients in the trial.
 #' @slot toxicity The toxicity outcome.
 #' @slot AUCs The AUCs.
+#' @slot TR The total number of simulations.
 #' @import methods
 #' @useDynLib dfpk, .registration = TRUE
 #' @export
-setClass("dosefinding", slots = list(model="character", pid="numeric", N ="numeric",time="numeric", dose = "numeric", conc="numeric", 
+setClass("dosefinding", slots = list(pid="numeric", N ="numeric",time="numeric", dose = "numeric", conc="numeric", 
           p_0 = "numeric", L = "numeric",  nchains = "numeric", niter = "numeric", nadapt = "numeric", new_dose = "numeric", 
-          theta = "numeric", dose_levels="matrix", toxicity= "matrix", AUCs="matrix"))
+          theta = "numeric", dose_levels="matrix", toxicity= "matrix", AUCs="matrix", TR="numeric"))
 
 #' An S4 class to represent a simulated scenarios.
-#'
+#' 
 #' @slot param_pk The subject's PK parameters.
 #' @slot n_pk The length of time sampling.
 #' @slot time The time sampling.
 #' @slot N  The total number of patients.
 #' @slot doses The doses levels of the drug. 
 #' @slot limit_tox  Threshold in the toxicity. 
-#' @slot omega2  A standard deviation of CL and V.
+#' @slot omega2  A standard deviation of clearance (CL) and volume (V).
 #' @slot omega_a A standard deviation omega_a.
 #' @slot conc The concentration of the drug (concentration without error).
 #' @slot conc_pred The predicted concentration of the drug (concentration with error). 
 #' @slot tox The toxicity outcomes.
 #' @slot tab The data summary of scenarios' outcomes.
-#' @slot parameters  The PK parameter's estimations of each patient.
-#' @slot alfa_AUC  AUC with sensitivity parameter. 
+#' @slot parameters The PK parameter's estimations of each patient.
+#' @slot alfa_AUC AUC with sensitivity parameter. 
 #' @import methods
 #' @useDynLib dfpk, .registration = TRUE
 #' @export
@@ -48,23 +48,45 @@ setClass("scen", representation(param_pk="numeric", n_pk="numeric", time="numeri
           tox="matrix", tab="matrix", parameters="matrix", alfa_AUC="numeric"
           ))
 
-#' @export
+
+#' An S4 class to present the next recommended dose level in an ongoing trial.
+#'
+#' @slot N The total number of enrolled patients.
+#' @slot y The toxicity outcome of each patient.
+#' @slot AUCs The AUCs values of each patient.
+#' @slot doses The doses levels of the drug.
+#' @slot x A vector of dose levels assigned to patients in the trial.
+#' @slot theta The toxicity (probability) target.
+#' @slot options The Stan model's options.
+#' @slot new_dose The next recommended dose level.
+#' @slot pstim The estimated probability of toxicity.
+#' @slot parameters The Stan model's estimated parameters.
+#' @import methods
+#' @useDynLib dfpk, .registration = TRUE
+#' @export 
+setClass("Dose", slots = list(N = "numeric", y = "logical", AUCs = "numeric", doses ="numeric", x = "numeric", 
+     theta = "numeric", options = "list", new_dose="numeric", pstim="numeric", parameters="numeric"
+     ))
+
+
+#' @export 
 setMethod(f = "show",
           signature ="dosefinding",
           definition = function(object) {
                cat("Today: ", date(), "\n") 
-     		cat("\n","Data Summary (", object@model,") \n")
+     		cat("\n","A. Data Summary", "\n")
+               cat("Number of simulations:", object@TR, "\n") 
      	     cat("Total number of patients in the trial:", object@N, "\n")
      	     cat("The time sampling:", object@time, "\n")
                cat("Levels of Doses:", object@dose, "\n")
                cat("Concentration of the drug:", object@conc, "\n")
                cat("Skeleton of CRM:", object@p_0, "\n")
-               cat("Threshold set before starting the trial:", object@L, "\n")
-               cat("\n","STAN Model's Options \n")
+               cat("Threshold set before starting the trial:", object@L, "\n") 
+               cat("\n","B. STAN Model's Options \n")
                cat("The Stan model runs with", object@nchains, "MCMC chains ")
                cat("which each chain has", object@niter, "iterations ")
                cat("and", object@nadapt, "warmup iterations \n")
-               cat("\n","Dose-Finding Results: \n")
+               cat("\n","C. Dose-Finding Results: \n") 
                cat("Next recommended dose level:", object@new_dose, "\n")
                cat("Recommendation is based on a target toxicity probability of:",object@theta, "\n")
                cat("Dose escalation in the trial:","\n", object@dose_levels,"\n")
@@ -72,11 +94,12 @@ setMethod(f = "show",
                print(object@toxicity)
                cat("AUCs: \n")
                print(object@AUCs)
-               cat("\n")
+               cat("\n") 
          }
 )
 
-#' @export
+
+#' @export 
 setMethod(f = "show",
           signature ="scen",
           definition = function(object) {
@@ -101,30 +124,65 @@ setMethod(f = "show",
                cat("\n")
                cat("The PK parameter's estimations for each patient are:", "\n")
                print(object@parameters)
-               cat("\n")
+               cat("\n") 
          }
+) 
+
+
+#' @export 
+setMethod(f = "show",
+          signature ="Dose",
+          definition = function(object) {
+               cat("Today: ", date(), "\n")
+               cat("Total number of enrolled patients in the trial: ", object@N, "\n")
+               cat("Levels of doses: ", object@doses, "\n")
+               cat("The Next Recommended Dose: ", "\n")
+               print(object@new_dose)
+               cat("\n")
+               cat("Estimated probability of toxicity: ", "\n")
+               print(object@pstim) 
+               cat("\n")
+               cat("Estimated model's parameters: ", "\n")
+               print(object@parameters)
+               cat("\n")
+          }
 )
 
-#######################################
-################ Plots ################
-#######################################
+###########################################
+################ Plots ####################
+###########################################
 
-#' The generic function of the plot.dose
+#' The generic function of the plot.dose.
 #'
 #' @param x A "dosefinding" object.
 #' @param ... Other parameters to be passed through to plotting functions. They are ignored in this function.
-#' @description 
+#' @description
 #' A graphical representation of dose escalation for each patient in the trial.
+#' 
+#' @author Artemis Toumazi \email{artemis.toumazi@@inserm.fr}, Moreno Ursino \email{moreno.ursino@@inserm.fr}, Sarah Zohar \email{sarah.zohar@@inserm.fr}
+#' 
+#' @references Ursino, M., et al, (2016) Dose-finding methods using pharmacokinetics in small populations (under review).
+#' 
+#' @seealso \code{\link{plotConc}}
+#' 
 #' @import graphics
 #' @useDynLib dfpk, .registration = TRUE
 #' @export
-setGeneric(name="plotDose",def = function(x,...){standardGeneric("plotDose")}
+setGeneric(name="plotDose", def = function(x,...){standardGeneric("plotDose")}
 )
 
+
 #' The graphical representation of dose escalation for each patient in the trial. 
 #' 
 #' @param x A "dosefinding" object.
 #' @param ... Other parameters to be passed through to plotting functions. They are ignored in this function.
+#'
+#' @author Artemis Toumazi \email{artemis.toumazi@@inserm.fr}, Moreno Ursino \email{moreno.ursino@@inserm.fr}, Sarah Zohar \email{sarah.zohar@@inserm.fr}
+#' 
+#' @references Ursino, M., et al, (2016) Dose-finding methods using pharmacokinetics in small populations (under review).
+#' 
+#' @seealso \code{\link{plotConc}}
+#'
 #' @import methods
 #' @import stats
 #' @import graphics
@@ -142,22 +200,37 @@ setMethod(f ="plotDose",
           }
 )
 
-#' The generic function of plot.conc
+#' The generic function of plot.conc.
 #' 
 #' @param x A "scen" object.
 #' @param ... Other parameters to be passed through to plotting functions. They are ignored in this function.
 #' @description 
 #' A graphical representation of drug's concentration in the plasma at time t.
+#'
+#' @author Artemis Toumazi \email{artemis.toumazi@@inserm.fr}, Moreno Ursino \email{moreno.ursino@@inserm.fr}, Sarah Zohar \email{sarah.zohar@@inserm.fr}
+#' 
+#' @references Ursino, M., et al, (2016) Dose-finding methods using pharmacokinetics in small populations (under review).
+#' 
+#' @seealso \code{\link{plotDose}}
+#'
 #' @import graphics
 #' @useDynLib dfpk, .registration = TRUE
-#' @export
-setGeneric(name="plotConc",def = function(x,...){standardGeneric("plotConc")}
+#' @export 
+setGeneric(name="plotConc", def = function(x,...){standardGeneric("plotConc")}
 )
 
+
 #' The graphical representation of the drug's concentration in the plasma at time t after the drug administration.
 #' 
 #' @param x A "scen" object.
 #' @param ... Other parameters to be passed through to plotting functions. They are ignored in this function.
+#'
+#' @author Artemis Toumazi \email{artemis.toumazi@@inserm.fr}, Moreno Ursino \email{moreno.ursino@@inserm.fr}, Sarah Zohar \email{sarah.zohar@@inserm.fr}
+#' 
+#' @references Ursino, M., et al, (2016) Dose-finding methods using pharmacokinetics in small populations (under review).
+#' 
+#' @seealso \code{\link{plotDose}}
+#'
 #' @import methods
 #' @import stats
 #' @import graphics
@@ -167,7 +240,7 @@ setGeneric(name="plotConc",def = function(x,...){standardGeneric("plotConc")}
 setMethod(f ="plotConc" ,signature ="scen", 
      definition = function(x,...){
           colors <- rainbow(length(x@doses))
-          plot(x@time, x@conc[,1], type="l", col=colors[1], xlab="Time (hours)", ylab="Concentration (mg)", main="Pharmacokinetics: Concentration vs Time", ylim=c(0,max(x@conc)),...)
+          plot(x@time, x@conc[,1], type="l", col=colors[1], xlab="Time (hours)", ylab="Concentration (mg/L)", main="Pharmacokinetics: Concentration vs Time", ylim=c(0,max(x@conc)),...)
      	    for(i in 2:length(x@doses)){
         	      lines(x@time, x@conc[,i], col=colors[i], lty=i,...)
     	          }
